Installation
============

Install is as simple as typing -

``pip install acccmip6``

Requires python v3.5 or up and pip. Mac users can use ``brew install python3`` and ``python get-pip.py`` from terminal. Windows users can use `Windows Subsystem`_.

You may also install the package via `conda`_ -

``conda install -c thassan acccmip6``

.. _`Windows Subsystem`: https://docs.microsoft.com/en-us/windows/wsl/install-win10

.. _`conda`: https://docs.conda.io/projects/conda/en/latest/user-guide/install/
